<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>tkConstants</name>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="135"/>
        <source>English</source>
        <translation>Français</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="138"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="139"/>
        <source>Recent files</source>
        <translation>Récents</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="141"/>
        <source>Edit</source>
        <translation>Éditer</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="142"/>
        <source>Selection</source>
        <translation>Sélection</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="143"/>
        <source>List</source>
        <translation>Liste</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="144"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="198"/>
        <source>Templates</source>
        <translation>Modèles</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="145"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="146"/>
        <source>Font</source>
        <translation>Police de caractères</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="147"/>
        <source>Paragraph</source>
        <translation>Paragraphes</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="148"/>
        <source>Table</source>
        <translation>Tableau</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="149"/>
        <source>Image</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="150"/>
        <source>Tools</source>
        <translation>Outils</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="151"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="575"/>
        <source>Plugins</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="152"/>
        <source>Configuration</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="153"/>
        <source>Toolbars</source>
        <translation>Boîtes à outils</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="154"/>
        <source>Languages</source>
        <translation>Langages</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="155"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="246"/>
        <source>Interpretor</source>
        <translation>Interpréteur</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="156"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="238"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="157"/>
        <source>About databases</source>
        <translation>À propos des bases de données</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="158"/>
        <source>Update available</source>
        <translation>Mise à jour disponible</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="161"/>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="162"/>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="163"/>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="164"/>
        <source>Save as</source>
        <translation>Sauvegarder sous</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="165"/>
        <source>Print...</source>
        <translation>Imprimer...</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="166"/>
        <source>Print preview</source>
        <translation>Prévisualisation</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="167"/>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="168"/>
        <source>Search...</source>
        <translation>Rechercher...</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="170"/>
        <source>New Patient</source>
        <translation>Nouveau Patient</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="171"/>
        <source>Remove Patient</source>
        <translation>Effacer Patient</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="172"/>
        <source>View Patient Identity</source>
        <translation>Voir l&apos;identité du patient</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="173"/>
        <source>Identity</source>
        <translation>Identité</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="175"/>
        <source>Open a prescription</source>
        <translation>Ouvrir une prescription</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="176"/>
        <source>Save a prescription</source>
        <translation>Sauvegarder une prescription</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="177"/>
        <source>Print a prescription</source>
        <translation>Imprimer la prescription</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="179"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="180"/>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="181"/>
        <source>Cut</source>
        <translation>Couper</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="182"/>
        <source>Paste</source>
        <translation>Coller</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="183"/>
        <source>Undo</source>
        <translation>Défaire</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="184"/>
        <source>Redo</source>
        <translation>Refaire</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="185"/>
        <source>Select All</source>
        <translation>Sélectionner tout</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="186"/>
        <source>Deselect</source>
        <translation>Désélectionner</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="187"/>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="188"/>
        <source>Previous</source>
        <translation>Précédent</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="189"/>
        <source>Home</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="190"/>
        <source>Add to list</source>
        <translation>Ajouter à la liste</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="192"/>
        <source>Move item up</source>
        <translation>Monter l&apos;item</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="193"/>
        <source>Move item down</source>
        <translation>Descendre l&apos;item</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="194"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="454"/>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="195"/>
        <source>Sort</source>
        <translation>Trier</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="196"/>
        <source>Web site</source>
        <translation>Site internet</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="199"/>
        <source>Create a new template</source>
        <translation>Créer un nouveau modèle</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="201"/>
        <source>Add a category</source>
        <translation>Ajouter une catégorie</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="202"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="203"/>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="204"/>
        <source>Lock</source>
        <translation>Vérouiller</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="205"/>
        <source>Unlock</source>
        <translation>Dévérouiller</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="206"/>
        <source>Locked</source>
        <translation>Vérouillé</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="207"/>
        <source>Unlocked</source>
        <translation>Dévérouillé</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="208"/>
        <source>Templates database information</source>
        <translation>Informations de la base de données des modèles</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="210"/>
        <source>PMHx</source>
        <translation>ATCD</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="211"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="300"/>
        <source>Past medical history</source>
        <translation>Antécédents</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="212"/>
        <source>PMHx preferences</source>
        <translation>Préférences des antécédents</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="214"/>
        <source>Bold</source>
        <translation>Gras</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="215"/>
        <source>Italic</source>
        <translation>Italique</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="216"/>
        <source>Underline</source>
        <translation>Souligner</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="217"/>
        <source>Strike</source>
        <translation>Barré</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="218"/>
        <source>Bigger</source>
        <translation>Plus grand</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="219"/>
        <source>Smaller</source>
        <translation>Plus petit</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="220"/>
        <source>Font format</source>
        <translation>Format de police</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="221"/>
        <source>Color</source>
        <translation>Couleur</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="222"/>
        <source>Table format</source>
        <translation>Format du tableau</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="223"/>
        <source>Image format</source>
        <translation>Format de l&apos;image</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="224"/>
        <source>Center</source>
        <translation>Centrer</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="225"/>
        <source>Left</source>
        <translation>Gauche</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="226"/>
        <source>Right</source>
        <translation>Droite</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="227"/>
        <source>Justify</source>
        <translation>Justifier</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="229"/>
        <source>Add table</source>
        <translation>Ajouter un tableau</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="230"/>
        <source>Table properties</source>
        <translation>Propriétés du tableau</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="231"/>
        <source>Add row</source>
        <translation>Ajouter une ligne</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="232"/>
        <source>Remove row</source>
        <translation>Enlever une ligne</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="233"/>
        <source>Add colunm</source>
        <translation>Ajouter une colonne</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="234"/>
        <source>Remove column</source>
        <translation>Enlever une colonne</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="235"/>
        <source>Merge cells</source>
        <translation>Fusionner les cellules</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="236"/>
        <source>Split cells</source>
        <translation>Eclater la cellule</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="239"/>
        <source>About Plugins</source>
        <translation>À propos des plugins</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="240"/>
        <source>About Qt</source>
        <translation>À propos de Qt</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="241"/>
        <source>About this form</source>
        <translation>À propos de ce formulaire</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="242"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="245"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="243"/>
        <source>Debugging tools</source>
        <translation>Outils de déboggage</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="244"/>
        <source>Display/Hide form&apos;s help text</source>
        <translation>Afficher/cacher les textes d&apos;aide des formulaires</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="247"/>
        <source>User manager</source>
        <translation>Gestionnaire de utilisateurs</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="248"/>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="249"/>
        <source>Application global configurator</source>
        <translation>Configurateur général de l&apos;application</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="250"/>
        <source>Configure MedinTux</source>
        <translation>Configurer MedinTux</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="251"/>
        <source>View update information</source>
        <translation>Voir les informations de mise à jour</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="252"/>
        <source>Print Preview</source>
        <translation>Prévisulisation de l&apos;impression</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="253"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="519"/>
        <source>Translators</source>
        <translation>Traducteurs</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="256"/>
        <source>Zoom in</source>
        <translation>Agrandir</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="257"/>
        <source>Zoom out</source>
        <translation>Réduire</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="259"/>
        <source>Navigation</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="260"/>
        <source>Defaults</source>
        <translation>Défauts</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="263"/>
        <source>Drugs database</source>
        <translation>Base de données thérapeutique</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="265"/>
        <source>Protocols database information</source>
        <translation>Informations de la base de données des protocoles</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="266"/>
        <source>Interactions database information</source>
        <translation>Informations de la base de données des interactions</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="268"/>
        <source>Interactions database</source>
        <translation>Base de données des interactions</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="271"/>
        <source>INN</source>
        <translation>DCI</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="272"/>
        <source>ATC</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="273"/>
        <source>intake(s)</source>
        <translation>prise(s)</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="274"/>
        <source>View synthetic interactions</source>
        <translation>Voir la synthèse des interactions</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="275"/>
        <source>from</source>
        <translation>de</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="276"/>
        <source>to</source>
        <translation>à</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="277"/>
        <source>from %1 to %2</source>
        <translation>de %1 à %2</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="278"/>
        <source>during</source>
        <translation>durant</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="279"/>
        <source>each</source>
        <translation>tous les</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="280"/>
        <source>and</source>
        <translation>et</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="281"/>
        <source>Allergy to %1</source>
        <translation>Allergie à %1</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="282"/>
        <source>Intolerance to %1</source>
        <translation>Intolérance à %1</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="283"/>
        <source>No known allergies / intolerances</source>
        <translation>Pas d&apos;allergies / intolérances connues</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="284"/>
        <source>Known allergies</source>
        <translation>Allergies connues</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="285"/>
        <source>Known intolerances</source>
        <translation>Intolérances connues</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="288"/>
        <source>Interaction</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="289"/>
        <source>Take into account</source>
        <translation>A prendre en compte</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="290"/>
        <source>Discouraged</source>
        <translation>Déconseillée</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="291"/>
        <source>Contraindication</source>
        <translation>Contre-indication</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="292"/>
        <source>Cytochrome P450 interaction</source>
        <translation>Interaction du cytochrome P450</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="293"/>
        <source>Glycoprotein-P interaction</source>
        <translation>Interaction de la glycoprotéine P</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="294"/>
        <source>Precaution for use</source>
        <translation>Précaution d&apos;utilisation</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="295"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="452"/>
        <source>Information</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="296"/>
        <source>Molecule is duplicated</source>
        <translation>La molécule est dupliquée</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="297"/>
        <source>Class is duplicated</source>
        <translation>La classe thérapeutique est dupliquée</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="304"/>
        <source>Bank details</source>
        <translation>Détails banquaires</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="305"/>
        <source>Available movements</source>
        <translation>Mouvements disponibles</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="306"/>
        <source>Medical procedures</source>
        <translation>Actes médicaux</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="307"/>
        <source>Sites</source>
        <translation>Sites</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="308"/>
        <source>Insurance</source>
        <translation>Assurance</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="309"/>
        <source>Percentages</source>
        <translation>Pourcentages</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="310"/>
        <source>Distance rules</source>
        <translation>Règles de distance</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="311"/>
        <source>Assets rates</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="314"/>
        <source>The %1 driver is not available.</source>
        <translation>Le pilote %1 n&apos;est pas disponible.</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="315"/>
        <source>The %1 database driver is not installed or can not be found. Please report this error to the developper.</source>
        <translation>Le pilote de base de données %1 n&apos;est pas installé ou ne peut pas être trouvé. Veuillez rapporter l&apos;erreur à l&apos;équipe de développement.</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="316"/>
        <source>Database %1: Schema error.</source>
        <translation>Base de données %1 : Erreur d&apos;architecture.</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="317"/>
        <source>Change password</source>
        <translation>Changer le mot de passe</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="318"/>
        <source>Login</source>
        <translation>Identifiant</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="319"/>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="322"/>
        <source>Duration</source>
        <translation>Durée</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="323"/>
        <source>second(s)</source>
        <translation>seconde(s)</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="324"/>
        <source>minute(s)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="325"/>
        <source>hour(s)</source>
        <translation>heure(s)</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="326"/>
        <source>day(s)</source>
        <translation>jour(s)</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="327"/>
        <source>week(s)</source>
        <translation>semaine(s)</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="328"/>
        <source>month(s)</source>
        <translation>mois</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="329"/>
        <source>quarter(s)</source>
        <translation>trimestre(s)</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="331"/>
        <source>decade(s)</source>
        <translation>décade(s)</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="333"/>
        <source>second</source>
        <translation>seconde</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="334"/>
        <source>minute</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="335"/>
        <source>hour</source>
        <translation>heure</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="336"/>
        <source>day</source>
        <translation>jour</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="337"/>
        <source>week</source>
        <translation>semaine</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="338"/>
        <source>month</source>
        <translation>mois</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="339"/>
        <source>quarter</source>
        <translation>trimestre</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="340"/>
        <source>year</source>
        <translation>année</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="341"/>
        <source>decade</source>
        <translation>décennie</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="343"/>
        <source>seconds</source>
        <translation>secondes</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="344"/>
        <source>minutes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="345"/>
        <source>hours</source>
        <translation>heures</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="346"/>
        <source>days</source>
        <translation>jours</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="347"/>
        <source>weeks</source>
        <translation>semaines</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="348"/>
        <source>months</source>
        <translation>mois</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="349"/>
        <source>quarters</source>
        <translation>trimestres</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="350"/>
        <source>years</source>
        <translation>années</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="351"/>
        <source>decades</source>
        <translation>décennies</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="354"/>
        <source>wake up</source>
        <translation>lever</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="355"/>
        <source>breakfast</source>
        <translation>petit-déjeuner</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="357"/>
        <source>morning</source>
        <translation>matin</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="358"/>
        <source>midday</source>
        <translation>midi</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="359"/>
        <source>lunch</source>
        <translation>déjeuner</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="360"/>
        <source>afternoon</source>
        <translation>après-midi</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="363"/>
        <source>evening</source>
        <translation>soir</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="364"/>
        <source>bedtime</source>
        <translation>coucher</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="368"/>
        <source>during meal</source>
        <translation>pendant le repas</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="369"/>
        <source>after meal</source>
        <translation>après le repas</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="370"/>
        <source>before meal</source>
        <translation>avant le repas</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="371"/>
        <source>not during meal</source>
        <translation>en dehors de repas</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="372"/>
        <source>only if meal</source>
        <translation>seulement si repas</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="373"/>
        <source>separated from food (1-2 hours)</source>
        <translation>à distance du repas (1 à 2 heures)</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="374"/>
        <source>suggested with food</source>
        <translation>prendre avec des aliments</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="375"/>
        <source>with or without food</source>
        <translation>prendre avec ou sans aliments</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="378"/>
        <source>Using library : %1</source>
        <translation>Utilise la librairie : %1</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="379"/>
        <source>Starting application at %1</source>
        <translation>Démarre l&apos;application %1</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="380"/>
        <source>Initializing Translations...</source>
        <translation>Intialise les traductions...</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="381"/>
        <source>Initializing libraries...</source>
        <translation>Initialise les librairies...</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="382"/>
        <source>Needed Licence Agreement...</source>
        <translation>Acceptation de la license requise...</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="383"/>
        <source>Checking directory structure...</source>
        <translation>Vérifie la structure du répertoire...</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="384"/>
        <source>Initializing Default Parameters...</source>
        <translation>Initialise les paramètres par défaut...</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="385"/>
        <source>Initializing Plugins...</source>
        <translation>Initialise les plugins...</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="386"/>
        <source>First time running</source>
        <translation>Premier démarrage</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="389"/>
        <source>Check for update</source>
        <translation>Vérifie les mises à jour</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="394"/>
        <source>Type</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="395"/>
        <source>Status</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="396"/>
        <source>ICD10</source>
        <translation>CIM10</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="397"/>
        <source>now</source>
        <translation>maintenant</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="398"/>
        <source>low</source>
        <translation>faible</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="399"/>
        <source>medium</source>
        <translation>moyen</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="400"/>
        <source>high</source>
        <translation>haut</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="401"/>
        <source>modify</source>
        <translation>modifier</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="404"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="406"/>
        <source>Settings recovered</source>
        <translation>Paramètres récupérés</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="408"/>
        <source>Show details</source>
        <translation>Montrer les détails</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="409"/>
        <source>More information</source>
        <translation>Plus d&apos;informations</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="410"/>
        <source>Hide extra information</source>
        <translation>Cacher les informations additionnelles</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="417"/>
        <source>Users</source>
        <translation>Utilisateurs</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="419"/>
        <source>Rights</source>
        <translation>Droits</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="420"/>
        <source>User rights</source>
        <translation>Droits de l&apos;utilisateurs</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="421"/>
        <source>Medical rights</source>
        <translation>Droits médicaux</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="422"/>
        <source>Administrative rights</source>
        <translation>Droits administratifs</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="423"/>
        <source>User manager rights</source>
        <translation>Droits du gestionnaire des utilisateurs</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="424"/>
        <source>Drug rights</source>
        <translation>Droits thérapeutiques</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="429"/>
        <source>Path</source>
        <translation>Répertoire</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="447"/>
        <source>Wrong number of tags (%1)</source>
        <translation>Nombre de tags incorrect (%1)</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="448"/>
        <source>Wrong root tag %1 %2.</source>
        <translation>Mauvais tag principal %1 %2.</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="449"/>
        <source>Document type name mismatch.</source>
        <translation>Type de document discordant.</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="486"/>
        <source>General preferences</source>
        <translation>Préférences générales</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="487"/>
        <source>User preferences</source>
        <translation>Préférences de l&apos;utilisateur</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="490"/>
        <source>Connected to database %1 with driver %2</source>
        <translation>Connecté à la base de données %1 avec le pilote %2</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="495"/>
        <source>User %1 correctly created</source>
        <translation>Utilisateur %1 correctement créé</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="538"/>
        <source>Agenda</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="539"/>
        <source>Agenda event</source>
        <translation>Rendez-vous</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="540"/>
        <source>Agenda events</source>
        <translation>Rendez-vous</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="541"/>
        <source>Agenda database information</source>
        <translation>Informations de la base de données des agendas</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="542"/>
        <source>No availability</source>
        <translation>Pas de disponibilité</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="543"/>
        <source>Attendee</source>
        <translation>Participant</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="544"/>
        <source>Attendees</source>
        <translation>Participants</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="545"/>
        <source>User delegate</source>
        <translation>Utilisateur délégué</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="546"/>
        <source>Owner</source>
        <translation>Propriétaire</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="547"/>
        <source>Today</source>
        <translation>Aujourd&apos;hui</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="548"/>
        <source>Tomorrow</source>
        <translation>Demain</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="549"/>
        <source>Yesterday</source>
        <translation>Hier</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="550"/>
        <source>Current week</source>
        <translation>Cette semaine</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="551"/>
        <source>Next week</source>
        <translation>La semaine prochaine</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="552"/>
        <source>Previous week</source>
        <translation>La semaine précédente</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="553"/>
        <source>Current month</source>
        <translation>Ce mois</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="554"/>
        <source>Next month</source>
        <translation>Le prochain mois</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="558"/>
        <source>Arrived</source>
        <translation>Arrivé</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="559"/>
        <source>Cancelled</source>
        <translation>Annulé</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="560"/>
        <source>Missed</source>
        <translation>Manqué (non excusé)</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="561"/>
        <source>Waiting</source>
        <translation>En attente</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="562"/>
        <source>Changed</source>
        <translation>Modifié</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="563"/>
        <source>Approved</source>
        <translation>Approuvé</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="566"/>
        <source>Zip archive (*.zip)</source>
        <translation>Archive ZIP (*.zip)</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="567"/>
        <source>HTML files (*.htm *.html)</source>
        <translation>Fichiers HTML (*.htm *.html)</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="568"/>
        <source>XML files (*.xml)</source>
        <translation>Fichiers XML (*.xml)</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="570"/>
        <source>Rich text files (*.rtf)</source>
        <translation>Fichiers texte enrichi (*.rtf)</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="571"/>
        <source>OpenOffice document (*.odt)</source>
        <translation>Document OpenOffice (*.odt)</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="572"/>
        <source>All files(*)</source>
        <translation>Tous les fichiers (*)</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="583"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="584"/>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="590"/>
        <source>Clear patient&apos;s information</source>
        <translation>Effacer les informations concernant le patient</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="594"/>
        <source>Gender</source>
        <translation>Genre</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="595"/>
        <source>Adress</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="607"/>
        <source>Nurse</source>
        <translation>Infirmière</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="609"/>
        <source>Caregiver</source>
        <translation>Aide-soignant</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="610"/>
        <source>Medical student</source>
        <translation>Etudiant en médecine</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="611"/>
        <source>Software administrator</source>
        <translation>Administrateur logiciel</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="648"/>
        <source>Add current date</source>
        <translation>Ajouter la date du jour</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="649"/>
        <source>Add user name</source>
        <translation>Ajouter le nom de l&apos;utilisateur</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="650"/>
        <source>Add patient name</source>
        <translation>Ajouter le nom du patient</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="651"/>
        <source>Add text</source>
        <translation>Ajouter du texte</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="660"/>
        <source>All languages</source>
        <translation>Tous les langages</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="661"/>
        <source>All other languages</source>
        <translation>Tous les autres langages</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="387"/>
        <source>This feature is not yet implemented.</source>
        <translation>Cette fonctionnalité n&apos;est pas encore disponible.</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="388"/>
        <source>Raising Application...</source>
        <translation>Application au premier plan...</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="390"/>
        <source>Checking for updates...</source>
        <translation>Vérifie les mises à jour...</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="391"/>
        <source>Initializing databases...</source>
        <translation>Initialise les bases de données...</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="413"/>
        <source>Welcome to FreeMedForms, you are now connected.</source>
        <translation>Bienvenue dans FreeMedForms, vous êtes maintenant connecté.</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="415"/>
        <source>No user connected.</source>
        <translation>Pas d&apos;utilisateur connecté.</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="430"/>
        <source>Path %1 does not exist</source>
        <translation>Le chemin %1 n&apos;existe pas</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="431"/>
        <source>Path %1 is not empty</source>
        <translation>Chemin %1 n&apos;est pas vide</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="432"/>
        <source>Path %1 contains dirs</source>
        <translation>Chemin %1 contient des répertoires</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="433"/>
        <source>Path %1 can not be removed</source>
        <translation>Chemin %1 ne peut pas être effacé</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="436"/>
        <source>File %1 does not exist</source>
        <translation>Fichier %1 n&apos;existe pas</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="437"/>
        <source>File %1 is not readable</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="438"/>
        <source>File %1 can not be removed</source>
        <translation>Fichier %1 ne peut pas être effacé</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="439"/>
        <source>File %1 loaded</source>
        <translation>Fichier %1 chargé</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="442"/>
        <source>Open file</source>
        <translation>Ouvrir un fichier</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="443"/>
        <source>Opening file %1</source>
        <translation>Ouvre le fichier %1</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="444"/>
        <source>Saving file %1</source>
        <translation>Sauvegarde le fichier %1</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="455"/>
        <source>Version</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="456"/>
        <source>Description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="459"/>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="460"/>
        <source>Ready</source>
        <translation>Prêt</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="463"/>
        <source>Messages</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="464"/>
        <source>Logged Messages</source>
        <translation>Messages enregistrés</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="465"/>
        <source>Errors</source>
        <translation>Erreurs</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="466"/>
        <source>Logged Errors</source>
        <translation>Erreurs enregistrées</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="467"/>
        <source>Informative message : %1</source>
        <translation>Information : %1</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="468"/>
        <source>Starting task : %1</source>
        <translation>Débute la tâche : %1</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="469"/>
        <source>posting message to : %1</source>
        <translation>envoie le message à : %1</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="470"/>
        <source>Error %1 occured while %2</source>
        <translation>L&apos;erreur %1 est survenue durant %2</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="471"/>
        <source>Error %1 : line %2, column %3</source>
        <translation>Erreur %1 : ligne %2, colonne %3</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="472"/>
        <source>Can not create %1 : it already exists</source>
        <translation>Impossible de créer %1 : il existe déjà</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="473"/>
        <source>Can not return %1 : it does not exists</source>
        <translation>Impossible de retourner %1 : il n&apos;existe pas</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="474"/>
        <source>Can not create %1 : no parent founded</source>
        <translation>Impossible de créer %1 : aucun parent trouvé</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="475"/>
        <source>%1 is not avaible</source>
        <translation>%1 n&apos;est pas disponible</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="476"/>
        <source>%1 is not avaible and can not be created</source>
        <translation>%1 n&apos;est pas disponible et ne peut pas être créé</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="477"/>
        <source>%1 are not avaible</source>
        <translation>%1 ne sont pas disponibles</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="478"/>
        <source>Setting %1 path to %2</source>
        <translation>Définit le répertoire de %1 à %2</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="479"/>
        <source>Error %1 from database %2</source>
        <translation>L&apos;erreur %1 est survenue depuis la base de données %2</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="407"/>
        <source>Creating default settings for %1</source>
        <translation>Création des paramètres par défaut pour %1</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="140"/>
        <source>Patient navigation</source>
        <translation>Navigation patient</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="191"/>
        <source>Remove from list</source>
        <translation>Retirer de la liste</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="200"/>
        <source>Toggle template view</source>
        <translation>Afficher/cacher la vue des modèles</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="255"/>
        <source>Toggle full screen</source>
        <translation>Sortir/revenir au mode plein écran</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="264"/>
        <source>Drugs database information</source>
        <translation>Informations de la base de données thérapeutiques</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="267"/>
        <source>Past medical history database information</source>
        <translation>Informations de la base de données des antécédents</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="269"/>
        <source>Drugs</source>
        <translation>Médicaments</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="270"/>
        <source>Protocols</source>
        <translation>Protocoles</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="303"/>
        <source>Accountancy</source>
        <translation>Comptabilité</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="330"/>
        <source>year(s)</source>
        <translation>année(s)</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="356"/>
        <source>mid-morning</source>
        <translation>Milieu de matinée</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="361"/>
        <source>mid-afternoon</source>
        <translation>Milieu d&apos;après-midi</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="362"/>
        <source>dinner</source>
        <translation>Dîner</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="367"/>
        <source>no meal relation</source>
        <translation>pas de relation avec le repas</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="405"/>
        <source>Reading settings file</source>
        <translation>Lecture du fichier de paramètres</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="414"/>
        <source>Connected as
  %1</source>
        <translation>Connecté sous
  %1</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="416"/>
        <source>User</source>
        <translation>Utilisateur</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="418"/>
        <source>User datas</source>
        <translation>Données de l&apos;utilisateur</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="426"/>
        <source>Save and restore</source>
        <translation>Sauvegarder et restaurer</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="434"/>
        <source>Path %1 can not be created</source>
        <translation>Le répertoire %1 ne peut pas être créé</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="435"/>
        <source>Creating dir %1</source>
        <translation>Crée le répertoire %1</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="440"/>
        <source>File %1 is empty</source>
        <translation>Fichier %1 vide</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="453"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="457"/>
        <source>Author</source>
        <translation>Auteur</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="458"/>
        <source>Provider</source>
        <translation>Fournisseur</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="461"/>
        <source>Available</source>
        <translation>Disponible</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="462"/>
        <source>Unavailable</source>
        <translation>Indisponible</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="480"/>
        <source>No object to translate</source>
        <translation>Pas d&apos;objet à traduite</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="481"/>
        <source>No %1 found.</source>
        <translation>Aucun %1 trouvé.</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="482"/>
        <source>Please describe your problem.</source>
        <translation>Décrivez votre problème.</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="483"/>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="484"/>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="485"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="488"/>
        <source>Fatal error : Application failure. Please restart application.</source>
        <translation>Erreur fatale. Veuillez redémarrer l&apos;application.</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="491"/>
        <source>Trying to create %1 
Place : %2</source>
        <translation>Essaie de créer %1 
Localisation : %2</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="492"/>
        <source>Unable to open database %1 : Error : %2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="493"/>
        <source>Unable to save data in database %1.</source>
        <translation>Impossible de sauvegarder les données dans la base de données %1.</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="494"/>
        <source>Database %1 correctly created</source>
        <translation>Base de données %1 créée correctement</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="496"/>
        <source>Database %1 can not be created. Error: %2.</source>
        <translation>Base de données %1 ne peut pas être créée. Erreur %2.</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="499"/>
        <source>Starting to send message.</source>
        <translation>Envoie du message.</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="500"/>
        <source>Message sended without error.</source>
        <translation>Message envoyé sans erreur.</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="501"/>
        <source>An error occured, message was not sended.</source>
        <translation>Une erreur est survenue, le message n&apos;a pas été envoyé.</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="502"/>
        <source>Checking for updates from %1</source>
        <translation>Vérifie les mises à jour depuis %1</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="503"/>
        <source>Version up to date</source>
        <translation>Version à jour</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="504"/>
        <source>Current version :</source>
        <translation>Version courante :</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="505"/>
        <source>Lastest version :</source>
        <translation>Dernière version :</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="506"/>
        <source>Update Available</source>
        <translation>Mise à jour disponible</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="509"/>
        <source>Creator and Main Developper</source>
        <translation>Créateur et développeur principal</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="510"/>
        <source>Developpers and Contributors</source>
        <translation>Développeurs et contributeurs</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="511"/>
        <source>Debugger advisor</source>
        <translation>Conseiller déboggage</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="512"/>
        <source>Developper and debugger advisor</source>
        <translation>Conseiller de développement et de déboggage</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="513"/>
        <source>Packager</source>
        <translation>Paqueteur</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="514"/>
        <source>Packager for %1</source>
        <translation>Empaqueteur pour %1</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="515"/>
        <source>Drugs Database Management</source>
        <translation>Gestionnaire de la base de données thérapeutique</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="516"/>
        <source>Medical advisors</source>
        <translation>Conseillers médicaux</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="517"/>
        <source>Medical advisor</source>
        <translation>Conseiller médical</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="518"/>
        <source>Webmaster</source>
        <translation>Maître toile</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="522"/>
        <source>Build information</source>
        <translation>Information de compilation</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="523"/>
        <source>Version information</source>
        <translation>Informations de version</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="524"/>
        <source>Build on %1 %2</source>
        <translation>Compilé : %1 %2</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="525"/>
        <source>Build version : %1</source>
        <translation>Version de compilation : %1</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="526"/>
        <source>Full application</source>
        <translation>Application complète</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="527"/>
        <source>SVN application</source>
        <translation>Application SVN</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="528"/>
        <source>Build in debug mode</source>
        <translation>Compilé en mode de déboggage</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="529"/>
        <source>Build in release mode</source>
        <translation>Compilé en mode stable</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="532"/>
        <source>Header</source>
        <translation>Entête</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="533"/>
        <source>Footer</source>
        <translation>Pied de page</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="534"/>
        <source>Watermark</source>
        <translation>Filigrane</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="535"/>
        <source>Printing</source>
        <translation>Impression</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="555"/>
        <source>Previous month</source>
        <translation>Le mois précédent</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="569"/>
        <source>Text files (*.txt)</source>
        <translation>Fichiers texte (*.txt)</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="578"/>
        <source>France</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="579"/>
        <source>Germany</source>
        <translation>Allemagne</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="580"/>
        <source>Canada</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="585"/>
        <source>Patient Name</source>
        <translation>Nom du patient</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="586"/>
        <source>Patient</source>
        <translation>Patient</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="587"/>
        <source>Patients</source>
        <translation>Patients</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="588"/>
        <source>Patient information</source>
        <translation>Informations sur le patient</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="589"/>
        <source>Patient database</source>
        <translation>Base de données patient</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="591"/>
        <source>Toggle patient&apos;s information</source>
        <translation>Afficher/cacher les informations concernant le patient</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="596"/>
        <source>Male</source>
        <translation>Masculin</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="597"/>
        <source>Female</source>
        <translation>Féminin</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="598"/>
        <source>Hermaphrodism</source>
        <translation>Hémaphrodisme</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="601"/>
        <source>Mister</source>
        <translation>Monsieur</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="602"/>
        <source>Miss</source>
        <translation>Mademoiselle</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="603"/>
        <source>Madam</source>
        <translation>Madame</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="604"/>
        <source>Doctor</source>
        <translation>Docteur</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="605"/>
        <source>Professor</source>
        <translation>Professeur</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="606"/>
        <source>Captain</source>
        <translation>Capitaine</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="608"/>
        <source>Secretary</source>
        <translation>Secrétaire</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="615"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="627"/>
        <source>Ctrl+L</source>
        <extracomment>Text Align Left shortcut key
----------
Text Align Left shortcut key : Mac specific</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="618"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="630"/>
        <source>Ctrl+R</source>
        <extracomment>Text Align Right shortcut key
----------
Text Align Right shortcut key : Mac specific</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="621"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="633"/>
        <source>Ctrl+E</source>
        <extracomment>Text Align Center shortcut key
----------
Text Align Center shortcut key : Mac specific</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="624"/>
        <location filename="../../libs/translationutils/constanttranslations.h" line="636"/>
        <source>Ctrl+J</source>
        <extracomment>Text Align Justify shortcut key
----------
Text Align Justify shortcut key : Mac specific</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="639"/>
        <source>Ctrl+Shift+T</source>
        <extracomment>Add table Editor shortcut key</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="644"/>
        <source>Toggle toolbar</source>
        <translation>Afficher/cacher la barre d&apos;outil</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="645"/>
        <source>Open in editor</source>
        <translation>Ouvrir dans l&apos;éditeur</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="646"/>
        <source>Save editor</source>
        <translation>Sauvegarder l&apos;éditeur</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="647"/>
        <source>Rich Text Editor</source>
        <translation>Éditeur de texte enrichi</translation>
    </message>
    <message>
        <location filename="../../libs/translationutils/constanttranslations.h" line="655"/>
        <source>Ctrl+Shift+P</source>
        <extracomment>ShortCut for &quot;Print prescription&quot;</extracomment>
        <translation></translation>
    </message>
</context>
</TS>
